@@ -10,28 +10,71 @@ import sys
 import threading
 from contextlib import contextmanager, suppress
 from functools import lru_cache
-from qt.core import (
-    QApplication, QBuffer, QByteArray, QColor, QDateTime, QDesktopServices, QDialog,
-    QDialogButtonBox, QEvent, QFile, QFileDialog, QFileIconProvider, QFileInfo, QFont,
-    QFontDatabase, QFontInfo, QFontMetrics, QGuiApplication, QIcon, QImageReader,
-    QImageWriter, QIODevice, QLocale, QNetworkProxyFactory, QObject, QPalette,
-    QResource, QSettings, QSocketNotifier, QStringListModel, Qt, QThread, QTimer,
-    QTranslator, QUrl, QWidget, pyqtSignal, pyqtSlot,
-)
 from threading import Lock, RLock
 
+from qt.core import (
+    QApplication,
+    QBuffer,
+    QByteArray,
+    QColor,
+    QDateTime,
+    QDesktopServices,
+    QDialog,
+    QDialogButtonBox,
+    QEvent,
+    QFile,
+    QFileDialog,
+    QFileIconProvider,
+    QFileInfo,
+    QFont,
+    QFontDatabase,
+    QFontInfo,
+    QFontMetrics,
+    QGuiApplication,
+    QIcon,
+    QImageReader,
+    QImageWriter,
+    QIODevice,
+    QLocale,
+    QNetworkProxyFactory,
+    QObject,
+    QPalette,
+    QResource,
+    QSettings,
+    QSocketNotifier,
+    QStringListModel,
+    Qt,
+    QThread,
+    QTimer,
+    QTranslator,
+    QUrl,
+    QWidget,
+    pyqtSignal,
+    pyqtSlot,
+)
+
 import calibre.gui2.pyqt6_compat as pqc
 from calibre import as_unicode, prints
 from calibre.constants import (
-    DEBUG, __appname__ as APP_UID, __version__, builtin_colors_dark,
-    builtin_colors_light, config_dir, is_running_from_develop, isbsd, isfrozen, islinux,
-    ismacos, iswindows, isxp, numeric_version, plugins_loc,
+    DEBUG,
+    __version__,
+    builtin_colors_dark,
+    builtin_colors_light,
+    config_dir,
+    is_running_from_develop,
+    isbsd,
+    isfrozen,
+    islinux,
+    ismacos,
+    iswindows,
+    isxp,
+    numeric_version,
+    plugins_loc,
 )
+from calibre.constants import __appname__ as APP_UID
 from calibre.ebooks.metadata import MetaInformation
 from calibre.gui2.geometry import geometry_for_restore_as_dict
-from calibre.gui2.linux_file_dialogs import (
-    check_for_linux_native_dialogs, linux_native_dialog,
-)
+from calibre.gui2.linux_file_dialogs import check_for_linux_native_dialogs, linux_native_dialog
 from calibre.gui2.palette import PaletteManager
 from calibre.gui2.qt_file_dialogs import FileDialog
 from calibre.ptempfile import base_dir
@@ -41,12 +84,15 @@ from calibre.utils.date import UNDEFINED_DATE
 from calibre.utils.file_type_icons import EXT_MAP
 from calibre.utils.img import set_image_allocation_limit
 from calibre.utils.localization import get_lang
-from calibre.utils.resources import get_image_path as I, get_path as P, user_dir
+from calibre.utils.resources import get_image_path as I
+from calibre.utils.resources import get_path as P
+from calibre.utils.resources import user_dir
 from polyglot import queue
 from polyglot.builtins import iteritems, string_or_bytes
 
 del pqc, geometry_for_restore_as_dict
 NO_URL_FORMATTING = QUrl.UrlFormattingOption.None_
+BOOK_DETAILS_DISPLAY_DEBOUNCE_DELAY = 100  # 100 ms is threshold for human visual response
 
 
 class IconResourceManager:
@@ -922,16 +968,12 @@ if not iswindows and not ismacos and 'CALIBRE_NO_NATIVE_FILEDIALOGS' not in os.e
     has_linux_file_dialog_helper = check_for_linux_native_dialogs()
 
 if has_windows_file_dialog_helper:
-    from calibre.gui2.win_file_dialogs import (
-        choose_dir, choose_files, choose_images, choose_save_file,
-    )
+    from calibre.gui2.win_file_dialogs import choose_dir, choose_files, choose_images, choose_save_file
 elif has_linux_file_dialog_helper:
     choose_dir, choose_files, choose_save_file, choose_images = map(
         linux_native_dialog, 'dir files save_file images'.split())
 else:
-    from calibre.gui2.qt_file_dialogs import (
-        choose_dir, choose_files, choose_images, choose_save_file,
-    )
+    from calibre.gui2.qt_file_dialogs import choose_dir, choose_files, choose_images, choose_save_file
     choose_files, choose_images, choose_dir, choose_save_file
 
 
@@ -1147,10 +1189,9 @@ class Application(QApplication):
             args = [override_program_name] + args[1:]
         self.palette_manager = PaletteManager(force_calibre_style, headless)
         if headless:
-            args.extend(('-platformpluginpath', plugins_loc, '-platform', 'headless'))
+            args.extend(('-platformpluginpath', plugins_loc, '-platform', os.environ.get('CALIBRE_HEADLESS_PLATFORM', 'headless')))
         else:
             args.extend(self.palette_manager.args_to_qt)
-
         self.headless = headless
         from calibre_extensions import progress_indicator
         self.pi = progress_indicator
@@ -1541,7 +1582,7 @@ def ensure_app(headless=True):
             args = sys.argv[:1]
             has_headless = ismacos or islinux or isbsd
             if headless and has_headless:
-                args += ['-platformpluginpath', plugins_loc, '-platform', 'headless']
+                args += ['-platformpluginpath', plugins_loc, '-platform', os.environ.get('CALIBRE_HEADLESS_PLATFORM', 'headless')]
                 if ismacos:
                     os.environ['QT_MAC_DISABLE_FOREGROUND_APPLICATION_TRANSFORM'] = '1'
             if headless and iswindows:
