@@ -7,11 +7,33 @@ import re
 from collections import namedtuple
 from contextlib import suppress
 from functools import lru_cache, partial
+
 from qt.core import (
-    QAction, QApplication, QClipboard, QColor, QDialog, QEasingCurve, QIcon,
-    QKeySequence, QMenu, QMimeData, QPainter, QPalette, QPen, QPixmap,
-    QPropertyAnimation, QRect, QSize, QSizePolicy, QSplitter, Qt, QTimer, QUrl, QWidget,
-    pyqtProperty, pyqtSignal,
+    QAction,
+    QApplication,
+    QClipboard,
+    QColor,
+    QDialog,
+    QEasingCurve,
+    QIcon,
+    QKeySequence,
+    QMenu,
+    QMimeData,
+    QPainter,
+    QPalette,
+    QPen,
+    QPixmap,
+    QPropertyAnimation,
+    QRect,
+    QSize,
+    QSizePolicy,
+    QSplitter,
+    Qt,
+    QTimer,
+    QUrl,
+    QWidget,
+    pyqtProperty,
+    pyqtSignal,
 )
 
 from calibre import fit_image, sanitize_file_name
@@ -20,18 +42,11 @@ from calibre.db.constants import DATA_DIR_NAME, DATA_FILE_PATTERN, RESOURCE_URL_
 from calibre.ebooks import BOOK_EXTENSIONS
 from calibre.ebooks.metadata.book.base import Metadata, field_metadata
 from calibre.ebooks.metadata.book.render import mi_to_html
-from calibre.ebooks.metadata.search_internet import (
-    all_author_searches, all_book_searches, name_for, url_for_author_search,
-    url_for_book_search,
-)
-from calibre.gui2 import (
-    NO_URL_FORMATTING, choose_save_file, config, default_author_link, gprefs,
-    pixmap_to_data, question_dialog, rating_font, safe_open_url,
-)
-from calibre.gui2.dialogs.confirm_delete import confirm, confirm as confirm_delete
-from calibre.gui2.dnd import (
-    dnd_get_files, dnd_get_image, dnd_has_extension, dnd_has_image, image_extensions,
-)
+from calibre.ebooks.metadata.search_internet import all_author_searches, all_book_searches, name_for, url_for_author_search, url_for_book_search
+from calibre.gui2 import NO_URL_FORMATTING, choose_save_file, config, default_author_link, gprefs, pixmap_to_data, question_dialog, rating_font, safe_open_url
+from calibre.gui2.dialogs.confirm_delete import confirm
+from calibre.gui2.dialogs.confirm_delete import confirm as confirm_delete
+from calibre.gui2.dnd import dnd_get_files, dnd_get_image, dnd_has_extension, dnd_has_image, image_extensions
 from calibre.gui2.widgets2 import HTMLDisplay
 from calibre.startup import connect_lambda
 from calibre.utils.config import tweaks
@@ -287,6 +302,17 @@ def render_html(mi, vertical, widget, all_fields=False, render_data_func=None,
                 ans = str(col.name())
         return ans
 
+    comments = ''
+    if comment_fields:
+        comments = '\n'.join('<div>%s</div>' % x for x in comment_fields)
+        # Comments cause issues with rendering in QTextBrowser
+        comments = comments_pat().sub('', comments)
+
+    html = render_parts(table, comments, vertical)
+    return html, table, comments
+
+
+def render_parts(table, comments, vertical):
     templ = '''\
     <html>
         <head></head>
@@ -295,11 +321,6 @@ def render_html(mi, vertical, widget, all_fields=False, render_data_func=None,
         </body>
     <html>
     '''%('vertical' if vertical else 'horizontal')
-    comments = ''
-    if comment_fields:
-        comments = '\n'.join('<div>%s</div>' % x for x in comment_fields)
-        # Comments cause issues with rendering in QTextBrowser
-        comments = comments_pat().sub('', comments)
     right_pane = comments
 
     if vertical:
@@ -424,6 +445,15 @@ def add_format_entries(menu, data, book_info, copy_menu, search_menu):
                 QIcon.ic('fts.png'))
 
 
+def add_link_submenu(menu: QMenu, link, book_info, field='', item_name=''):
+    if field and item_name:
+        m = menu.addMenu(QIcon.ic('external-link'), _('Associated link'))
+        m.addAction(QIcon.ic('reference'), _('Open: {}').format(link), lambda : book_info.link_clicked.emit(link))
+        m.addAction(QIcon.ic('minus'), _('Remove the link').format(link), lambda : book_info.link_removal_requested.emit(field, item_name))
+    else:
+        menu.addAction(QIcon.ic('external-link'), _('Open associated link').format(link), lambda : book_info.link_clicked.emit(link))
+
+
 def add_item_specific_entries(menu, data, book_info, copy_menu, search_menu):
     from calibre.gui2.ui import get_gui
     search_internet_added = False
@@ -465,8 +495,7 @@ def add_item_specific_entries(menu, data, book_info, copy_menu, search_menu):
         link_map = get_gui().current_db.new_api.get_all_link_maps_for_book(data.get('book_id', -1))
         link = link_map.get("authors", {}).get(author)
         if link:
-            menu.addAction(QIcon.ic('external-link'), _('Open associated link'),
-                           lambda : book_info.link_clicked.emit(link))
+            add_link_submenu(menu, link, book_info, 'authors', author)
     elif dt in ('path', 'devpath'):
         path = data['loc']
         ac = book_info.copy_link_action
@@ -517,16 +546,16 @@ def add_item_specific_entries(menu, data, book_info, copy_menu, search_menu):
                 v = data.get('original_value') or data.get('value')
                 copy_menu.addAction(QIcon.ic('edit-copy.png'), _('The text: {}').format(v),
                                         lambda: QApplication.instance().clipboard().setText(v))
-            ac = book_info.remove_item_action
-            ac.data = (field, remove_value, book_id)
-            ac.setText(_('Remove %s from this book') % escape_for_menu(remove_name or data.get('original_value') or value))
-            menu.addAction(ac)
+            if field != 'size':
+                ac = book_info.remove_item_action
+                ac.data = (field, remove_value, book_id)
+                ac.setText(_('Remove %s from this book') % escape_for_menu(remove_name or data.get('original_value') or value))
+                menu.addAction(ac)
             # See if we need to add a click associated link menu line
             link_map = get_gui().current_db.new_api.get_all_link_maps_for_book(data.get('book_id', -1))
             link = link_map.get(field, {}).get(value)
             if link:
-                menu.addAction(QIcon.ic('external-link'), _('Open associated link'),
-                               lambda : book_info.link_clicked.emit(link))
+                add_link_submenu(menu, link, book_info, field, value)
         else:
             v = data.get('original_value') or data.get('value')
             if v:
@@ -644,7 +673,7 @@ def details_context_menu_event(view, ev, book_info, add_popup_action=False, edit
             ac.current_url = url
             ac.setText(_('Copy link location'))
             menu.addAction(ac)
-            menu.addAction(QIcon.ic('external-link'), _('Open associated link'), lambda : book_info.link_clicked.emit(url))
+            add_link_submenu(menu, url, book_info)
     if not copy_links_added:
         create_copy_links(copy_menu)
 
@@ -712,7 +741,7 @@ class CoverView(QWidget):  # {{{
     def __init__(self, vertical, parent=None):
         QWidget.__init__(self, parent)
         self._current_pixmap_size = QSize(120, 120)
-        self.vertical = vertical
+        self.change_layout(vertical)
 
         self.animation = QPropertyAnimation(self, b'current_pixmap_size', self)
         self.animation.setEasingCurve(QEasingCurve(QEasingCurve.Type.OutExpo))
@@ -720,9 +749,6 @@ class CoverView(QWidget):  # {{{
         self.animation.setStartValue(QSize(0, 0))
         self.animation.valueChanged.connect(self.value_changed)
 
-        self.setSizePolicy(
-                QSizePolicy.Policy.Expanding if vertical else QSizePolicy.Policy.Minimum,
-                QSizePolicy.Policy.Expanding)
 
         self.default_pixmap = QApplication.instance().cached_qpixmap('default_cover.png', device_pixel_ratio=self.devicePixelRatio())
         self.pixmap = self.default_pixmap
@@ -732,6 +758,12 @@ class CoverView(QWidget):  # {{{
 
         self.do_layout()
 
+    def change_layout(self, vertical):
+        self.vertical = vertical
+        self.setSizePolicy(
+                QSizePolicy.Policy.Expanding if vertical else QSizePolicy.Policy.Minimum,
+                QSizePolicy.Policy.Expanding)
+
     def value_changed(self, val):
         self.update()
 
@@ -971,6 +1003,7 @@ class CoverView(QWidget):  # {{{
 class BookInfo(HTMLDisplay):
 
     link_clicked = pyqtSignal(object)
+    link_removal_requested = pyqtSignal(object, object)
     remove_format = pyqtSignal(int, object)
     remove_item = pyqtSignal(int, object, object)
     save_format = pyqtSignal(int, object)
@@ -988,6 +1021,8 @@ class BookInfo(HTMLDisplay):
     def __init__(self, vertical, parent=None):
         HTMLDisplay.__init__(self, parent=parent, save_resources_in_document=False)
         self.vertical = vertical
+        self.last_rendered_html = '', '', ''
+        self.base_url_for_current_book = None
         self.anchor_clicked.connect(self.link_activated)
         for x, icon in [
             ('remove_format', 'trash.png'), ('save_format', 'save.png'),
@@ -1015,6 +1050,14 @@ class BookInfo(HTMLDisplay):
         self.setFocusPolicy(Qt.FocusPolicy.NoFocus)
         self.setDefaultStyleSheet(css())
 
+    def change_layout(self, vertical):
+        if vertical != self.vertical:
+            self.vertical = vertical
+            if self.last_rendered_html[0]:
+                html = render_parts(self.last_rendered_html[1], self.last_rendered_html[2], self.vertical)
+                self.last_rendered_html = html, self.last_rendered_html[1], self.last_rendered_html[2]
+                self.setHtml(html)
+
     def refresh_css(self):
         self.setDefaultStyleSheet(css(True))
 
@@ -1069,9 +1112,14 @@ class BookInfo(HTMLDisplay):
         self.link_clicked.emit(link)
 
     def show_data(self, mi):
-        html = render_html(mi, self.vertical, self.parent())
+        html, table, comments = self.last_rendered_html = render_html(mi, self.vertical, self.parent())
+        path = getattr(mi, 'path', None)
+        self.base_url_for_current_book = QUrl.fromLocalFile(os.path.join(path, 'metadata.opf')) if path else None
         set_html(mi, html, self)
 
+    def get_base_qurl(self):
+        return self.base_url_for_current_book
+
     def process_external_css(self, css):
         return resolve_colors(css)
 
@@ -1114,7 +1162,6 @@ class DetailsLayout(QSplitter):  # {{{
         super().__init__(orientation, parent)
         self.vertical = vertical
         self._children = []
-        self.min_size = QSize(190, 200) if vertical else QSize(120, 120)
         self.setContentsMargins(0, 0, 0, 0)
         self.splitterMoved.connect(self.do_splitter_moved,
                                    type=Qt.ConnectionType.QueuedConnection)
@@ -1123,6 +1170,10 @@ class DetailsLayout(QSplitter):  # {{{
         self.resize_timer.setInterval(5)
         self.resize_timer.timeout.connect(self.do_resize)
 
+    def change_layout(self, vertical):
+        self.vertical = vertical
+        self.restore_splitter_state()
+
     def do_resize(self, *args):
         super().resizeEvent(self._resize_ev)
         self.do_layout(self.rect())
@@ -1134,7 +1185,7 @@ class DetailsLayout(QSplitter):  # {{{
         self.resize_timer.start()
 
     def minimumSize(self):
-        return QSize(self.min_size)
+        return QSize(190, 200) if self.vertical else QSize(120, 120)
 
     def addWidget(self, child):
         if len(self._children) > 2:
@@ -1145,10 +1196,16 @@ class DetailsLayout(QSplitter):  # {{{
         return len(self._children)
 
     def sizeHint(self):
-        return QSize(self.min_size)
+        return self.minimumSize()
+
+    @property
+    def splitter_state_pref_name(self):
+        return 'book_details_widget_splitter_state_' + ('vertical' if self.vertical else 'horizontal')
 
     def restore_splitter_state(self):
-        s = gprefs.get('book_details_widget_splitter_state')
+        s = gprefs.get(self.splitter_state_pref_name)
+        if s is None:
+            s = gprefs.get('book_details_widget_splitter_state')
         if s is None:
             # Without this on first start the splitter is rendered over the cover
             self.setSizes([20, 80])
@@ -1156,12 +1213,12 @@ class DetailsLayout(QSplitter):  # {{{
             self.restoreState(s)
         self.setOrientation(Qt.Orientation.Vertical if self.vertical else Qt.Orientation.Horizontal)
 
-    def setGeometry(self, r):
-        super().setGeometry(r)
-        self.do_layout(r)
+    def setGeometry(self, *a):
+        super().setGeometry(*a)
+        self.do_layout(self.geometry())
 
     def do_splitter_moved(self, *args):
-        gprefs['book_details_widget_splitter_state'] = bytearray(self.saveState())
+        gprefs[self.splitter_state_pref_name] = bytearray(self.saveState())
         self._children[0].do_layout()
 
     def cover_height(self, r):
@@ -1214,34 +1271,14 @@ class DetailsLayout(QSplitter):  # {{{
         cover.do_layout()
 # }}}
 
+# Drag 'n drop {{{
 
-class BookDetails(DetailsLayout):  # {{{
-
-    show_book_info = pyqtSignal()
-    open_containing_folder = pyqtSignal(int)
-    open_data_folder = pyqtSignal(int)
-    view_specific_format = pyqtSignal(int, object)
-    search_requested = pyqtSignal(object, object)
-    remove_specific_format = pyqtSignal(int, object)
-    remove_metadata_item = pyqtSignal(int, object, object)
-    save_specific_format = pyqtSignal(int, object)
-    restore_specific_format = pyqtSignal(int, object)
-    set_cover_from_format = pyqtSignal(int, object)
-    compare_specific_format = pyqtSignal(int, object)
-    copy_link = pyqtSignal(object)
-    remote_file_dropped = pyqtSignal(object, object)
+class DropMixin:
     files_dropped = pyqtSignal(object, object)
-    cover_changed = pyqtSignal(object, object)
-    open_cover_with = pyqtSignal(object, object)
-    cover_removed = pyqtSignal(object)
-    view_device_book = pyqtSignal(object)
-    manage_category = pyqtSignal(object, object)
-    edit_identifiers = pyqtSignal()
-    open_fmt_with = pyqtSignal(int, object, object)
-    edit_book = pyqtSignal(int, object)
-    find_in_tag_browser = pyqtSignal(object, object)
+    remote_file_dropped = pyqtSignal(object, object)
 
-    # Drag 'n drop {{{
+    def __init__(self):
+        self.setAcceptDrops(True)
 
     def dragEnterEvent(self, event):
         md = event.mimeData()
@@ -1287,10 +1324,35 @@ class BookDetails(DetailsLayout):  # {{{
 
     # }}}
 
+
+class BookDetails(DetailsLayout, DropMixin):  # {{{
+
+    show_book_info = pyqtSignal()
+    open_containing_folder = pyqtSignal(int)
+    open_data_folder = pyqtSignal(int)
+    view_specific_format = pyqtSignal(int, object)
+    search_requested = pyqtSignal(object, object)
+    remove_specific_format = pyqtSignal(int, object)
+    remove_metadata_item = pyqtSignal(int, object, object)
+    save_specific_format = pyqtSignal(int, object)
+    restore_specific_format = pyqtSignal(int, object)
+    set_cover_from_format = pyqtSignal(int, object)
+    compare_specific_format = pyqtSignal(int, object)
+    copy_link = pyqtSignal(object)
+    cover_changed = pyqtSignal(object, object)
+    open_cover_with = pyqtSignal(object, object)
+    cover_removed = pyqtSignal(object)
+    view_device_book = pyqtSignal(object)
+    manage_category = pyqtSignal(object, object)
+    edit_identifiers = pyqtSignal()
+    open_fmt_with = pyqtSignal(int, object, object)
+    edit_book = pyqtSignal(int, object)
+    find_in_tag_browser = pyqtSignal(object, object)
+
     def __init__(self, vertical, parent=None):
-        DetailsLayout.__init__(self, vertical, parent)
+        super().__init__(vertical, parent)
+        DropMixin.__init__(self)
         self.last_data = {}
-        self.setAcceptDrops(True)
         self._layout = self
         self.current_path = ''
 
@@ -1306,6 +1368,7 @@ class BookDetails(DetailsLayout):  # {{{
         self.book_info.search_requested = self.search_requested.emit
         self._layout.addWidget(self.book_info)
         self.book_info.link_clicked.connect(self.handle_click)
+        self.book_info.link_removal_requested.connect(self.remove_link)
         self.book_info.remove_format.connect(self.remove_specific_format)
         self.book_info.remove_item.connect(self.remove_metadata_item)
         self.book_info.open_fmt_with.connect(self.open_fmt_with)
@@ -1320,6 +1383,13 @@ class BookDetails(DetailsLayout):  # {{{
         self.book_info.edit_identifiers.connect(self.edit_identifiers)
         self.setCursor(Qt.CursorShape.PointingHandCursor)
 
+    def change_layout(self, vertical):
+        if vertical != self.vertical:
+            super().change_layout(vertical)
+            self.cover_view.change_layout(vertical)
+            self.book_info.change_layout(vertical)
+            self.do_layout(self.rect())
+
     def search_internet(self, data):
         if self.last_data:
             if data.author is None:
@@ -1398,6 +1468,16 @@ class BookDetails(DetailsLayout):  # {{{
     def handle_click(self, link):
         self.handle_click_from_popup(link)
 
+    def remove_link(self, field, item_value):
+        from calibre.gui2.ui import get_gui
+        gui = get_gui()
+        db = gui.current_db.new_api
+        db.set_link_map(field, {item_value: ''})
+        m = gui.library_view.model()
+        current = gui.library_view.currentIndex()
+        m.current_changed(current, current)
+        gui.tags_view.recount()
+
     def show_notes(self, field, item_id, parent=None):
         from calibre.gui2.dialogs.show_category_note import ShowNoteDialog
         from calibre.gui2.ui import get_gui
